Learn R Programming

SEAHORS (version 1.8.0)

cassenade.refits: Dataset: refitting relationships between objects found at the Palaeolithic Cassenade site

Description

Cassenade is a Palaeolithic site excavated...

Usage

data(cassenade)

Arguments

Format

  • cassenade.refits is a 81x10 matrix, describing the refitting relationships between objects at the Cassenade site.

References

  • Discamps, E. 2023. Field database of Cassenade excavations (2012-2013), Nakala, DOI: 10.34847/nkl.e30aie2u.

  • Discamps, E., F. Bachellerie, M. Baillet, L. Sitzia. 2019. The Use of Spatial Taphonomy for Interpreting Pleistocene Palimpsests: An Interdisciplinary Approach to the Châtelperronian and Carnivore Occupations at Cassenade (Dordogne, France), PaleoAnthropology, p. 362-388.

Examples

Run this code
data(cassenade)

Run the code above in your browser using DataLab